@@ -119,22 +119,22 @@ BasicBayesian <- function(ENV=parent.frame()){
 #' }
 #' \subsection{class(obj)="HDP"}{
 #' Where
-#'      \deqn{G_j|gamma \sim DP(gamma,U), j = 1:J}
-#'      \deqn{pi_j|G_j,alpha \sim DP(alpha,G_j)}
+#'      \deqn{G|gamma \sim DP(gamma,U)}
+#'      \deqn{pi_j|G,alpha \sim DP(alpha,G), j = 1:J}
 #'      \deqn{z|pi_j \sim Categorical(pi_j)}
-#'      \deqn{k|z,G_j \sim Categorical(G_j), if z is a sample from the base measure G}
+#'      \deqn{k|z,G \sim Categorical(G),\textrm{ if z is a sample from the base measure G}}
 #'      \deqn{theta_k|psi \sim H0(psi)}
 #' The sufficient statistics of "HDP" object is the same sufficient statistics of the "BasicBayesian" inside the "HDP".
 #' See \code{?sufficientStatistics.HDP} for details.
 #' }
 #' \subsection{class(obj)="HDP2"}{
 #' Where
-#'      \deqn{G_m |eta \sim DP(eta,U), m = 1:M}
-#'      \deqn{G_mj|gamma,G_m \sim DP(gamma,G_m), j = 1:J_m}
-#'      \deqn{pi_mj|G_mj,alpha \sim DP(alpha,G_mj)}
-#'      \deqn{z|pi_mj \sim Categorical(pi_mj)}
-#'      \deqn{k|z,G_mj \sim Categorical(G_mj), if z is a sample from the base measure G_mj}
-#'      \deqn{u|k,G_m \sim Categorical(G_m), if k is a sample from the base measure G_m}
+#'      \deqn{G |eta \sim DP(eta,U)}
+#'      \deqn{G_m|gamma,G \sim DP(gamma,G), m = 1:M}
+#'      \deqn{pi_{mj}|G_m,alpha \sim DP(alpha,G_m), j = 1:J_m}
+#'      \deqn{z|pi_{mj} \sim Categorical(pi_{mj})}
+#'      \deqn{k|z,G_m \sim Categorical(G_m),\textrm{ if z is a sample from the base measure} G_m}
+#'      \deqn{u|k,G \sim Categorical(G),\textrm{ if k is a sample from the base measure} G}
 #'      \deqn{theta_u|psi \sim H0(psi)}
 #'      \deqn{x|theta_u,u \sim F(theta_u)}
 #' The sufficient statistics of "HDP2" object is the same sufficient statistics of the "BasicBayesian" inside the "HDP2".
@@ -247,22 +247,22 @@ sufficientStatistics <- function(obj,x,...) UseMethod("sufficientStatistics")
 #' }
 #' \subsection{class(obj)="HDP"}{
 #' Where
-#'      \deqn{G_j|gamma \sim DP(gamma,U), j = 1:J}
-#'      \deqn{pi_j|G_j,alpha \sim DP(alpha,G_j)}
+#'      \deqn{G|gamma \sim DP(gamma,U)}
+#'      \deqn{pi_j|G,alpha \sim DP(alpha,G), j = 1:J}
 #'      \deqn{z|pi_j \sim Categorical(pi_j)}
-#'      \deqn{k|z,G_j \sim Categorical(G_j), if z is a sample from the base measure G}
+#'      \deqn{k|z,G \sim Categorical(G),\textrm{ if z is a sample from the base measure G}}
 #'      \deqn{theta_k|psi \sim H0(psi)}
 #' The sufficient statistics of "HDP" object is the same sufficient statistics of the "BasicBayesian" inside the "HDP".
 #' See \code{?sufficientStatistics_Weighted.HDP} for details.
 #' }
 #' \subsection{class(obj)="HDP2"}{
 #' Where
-#'      \deqn{G_m |eta \sim DP(eta,U), m = 1:M}
-#'      \deqn{G_mj|gamma,G_m \sim DP(gamma,G_m), j = 1:J_m}
-#'      \deqn{pi_mj|G_mj,alpha \sim DP(alpha,G_mj)}
-#'      \deqn{z|pi_mj \sim Categorical(pi_mj)}
-#'      \deqn{k|z,G_mj \sim Categorical(G_mj), if z is a sample from the base measure G_mj}
-#'      \deqn{u|k,G_m \sim Categorical(G_m), if k is a sample from the base measure G_m}
+#'      \deqn{G |eta \sim DP(eta,U)}
+#'      \deqn{G_m|gamma,G \sim DP(gamma,G), m = 1:M}
+#'      \deqn{pi_{mj}|G_m,alpha \sim DP(alpha,G_m), j = 1:J_m}
+#'      \deqn{z|pi_{mj} \sim Categorical(pi_{mj})}
+#'      \deqn{k|z,G_m \sim Categorical(G_m),\textrm{ if z is a sample from the base measure } G_m}
+#'      \deqn{u|k,G \sim Categorical(G),\textrm{ if k is a sample from the base measure } G_m}
 #'      \deqn{theta_u|psi \sim H0(psi)}
 #'      \deqn{x|theta_u,u \sim F(theta_u)}
 #' The sufficient statistics of "HDP2" object is the same sufficient statistics of the "BasicBayesian" inside the "HDP2".
@@ -362,22 +362,22 @@ posterior_bySufficientStatistics <- function(obj,...) UseMethod("posterior_bySuf
 #' }
 #' \subsection{class(obj)="HDP"}{
 #' Where
-#'      \deqn{G_j|gamma \sim DP(gamma,U), j = 1:J}
-#'      \deqn{pi_j|G_j,alpha \sim DP(alpha,G_j)}
+#'      \deqn{G|gamma \sim DP(gamma,U)}
+#'      \deqn{pi_j|G,alpha \sim DP(alpha,G), j = 1:J}
 #'      \deqn{z|pi_j \sim Categorical(pi_j)}
-#'      \deqn{k|z,G_j \sim Categorical(G_j), if z is a sample from the base measure G}
+#'      \deqn{k|z,G \sim Categorical(G),\textrm{ if z is a sample from the base measure G}}
 #'      \deqn{theta_k|psi \sim H0(psi)}
 #' \code{posterior()} will update gamma, alpha and psi in obj.
 #' See \code{?posterior.HDP} for details.
 #' }
 #' \subsection{class(obj)="HDP2"}{
 #' Where
-#'      \deqn{G_m |eta \sim DP(eta,U), m = 1:M}
-#'      \deqn{G_mj|gamma,G_m \sim DP(gamma,G_m), j = 1:J_m}
-#'      \deqn{pi_mj|G_mj,alpha \sim DP(alpha,G_mj)}
-#'      \deqn{z|pi_mj \sim Categorical(pi_mj)}
-#'      \deqn{k|z,G_mj \sim Categorical(G_mj), if z is a sample from the base measure G_mj}
-#'      \deqn{u|k,G_m \sim Categorical(G_m), if k is a sample from the base measure G_m}
+#'      \deqn{G |eta \sim DP(eta,U)}
+#'      \deqn{G_m|gamma,G \sim DP(gamma,G), m = 1:M}
+#'      \deqn{pi_{mj}|G_m,alpha \sim DP(alpha,G_m), j = 1:J_m}
+#'      \deqn{z|pi_{mj} \sim Categorical(pi_{mj})}
+#'      \deqn{k|z,G_m \sim Categorical(G_m),\textrm{ if z is a sample from the base measure } G_m}
+#'      \deqn{u|k,G \sim Categorical(G),\textrm{ if k is a sample from the base measure} G}
 #'      \deqn{theta_u|psi \sim H0(psi)}
 #'      \deqn{x|theta_u,u \sim F(theta_u)}
 #' \code{posterior()} will update eta, gamma, alpha and psi in obj.
@@ -469,22 +469,22 @@ posteriorDiscard_bySufficientStatistics <- function(obj,...) UseMethod("posterio
 #' }
 #' \subsection{class(obj)="HDP"}{
 #' Where
-#'      \deqn{G_j|gamma \sim DP(gamma,U), j = 1:J}
-#'      \deqn{pi_j|G_j,alpha \sim DP(alpha,G_j)}
+#'      \deqn{G|gamma \sim DP(gamma,U)}
+#'      \deqn{pi_j|G,alpha \sim DP(alpha,G), j = 1:J}
 #'      \deqn{z|pi_j \sim Categorical(pi_j)}
-#'      \deqn{k|z,G_j \sim Categorical(G_j), if z is a sample from the base measure G}
+#'      \deqn{k|z,G \sim Categorical(G),\textrm{ if z is a sample from the base measure } G}
 #'      \deqn{theta_k|psi \sim H0(psi)}
 #' \code{posteriorDiscard()} will update gamma, alpha and psi in obj.
 #' See \code{?posteriorDiscard.HDP} for details.
 #' }
 #' \subsection{class(obj)="HDP2"}{
 #' Where
-#'      \deqn{G_m |eta \sim DP(eta,U), m = 1:M}
-#'      \deqn{G_mj|gamma,G_m \sim DP(gamma,G_m), j = 1:J_m}
-#'      \deqn{pi_mj|G_mj,alpha \sim DP(alpha,G_mj)}
-#'      \deqn{z|pi_mj \sim Categorical(pi_mj)}
-#'      \deqn{k|z,G_mj \sim Categorical(G_mj), if z is a sample from the base measure G_mj}
-#'      \deqn{u|k,G_m \sim Categorical(G_m), if k is a sample from the base measure G_m}
+#'      \deqn{G |eta \sim DP(eta,U)}
+#'      \deqn{G_m|gamma,G \sim DP(gamma,G), m = 1:M}
+#'      \deqn{pi_{mj}|G_m,alpha \sim DP(alpha,G_m), j = 1:J_m}
+#'      \deqn{z|pi_{mj} \sim Categorical(pi_{mj})}
+#'      \deqn{k|z,G_m \sim Categorical(G_m),\textrm{ if z is a sample from the base measure } G_m}
+#'      \deqn{u|k,G \sim Categorical(G),\textrm{ if k is a sample from the base measure } G}
 #'      \deqn{theta_u|psi \sim H0(psi)}
 #'      \deqn{x|theta_u,u \sim F(theta_u)}
 #' \code{posteriorDiscard()} will update eta, gamma, alpha and psi in obj.
@@ -1151,13 +1151,15 @@ pdsDeterminant <- function(S,LOG=FALSE){
 #' @title additional release questions
 #' @description This is a list of additional questions you want devtools::release() to ask when releasing your package.
 release_questions <- function(){
-  c("Have you set the correct version number?",
-    "Have you removed the irrelevant code blocks, such as 'if(FALSE){...}', from your R files?",
-    "Have you add all the files in ./R folder to DESCRIPTION?",
-    "Have you removed the unfinished examples from the vignette?",
-    "Have you add all the references to README and function documentation?",
-    "Have you replaced all of the dontrun{} with donttest{}?",
-    "Have you rebuilt README.md from README.raw.md, using publish_markdown.r? Note that you have to rebuild README.md whenever you modified README.raw.md.",
-    "Have you removed all the par() settings in the examples? Check your documentations by run \"grep 'par(' ./man/*\" from the terminal."
-    )
+    c("Have you run 'R CMD build PACKAGE_FOLDER' and 'R CMD check PACKAGE_VERSION.tar.gz' before the release?",
+      "Have you removed underscores '_' in \\text{...}? For exmple \\text{G_m} is not allowed!!",
+      "Have you set the correct version number?",
+      "Have you removed the irrelevant code blocks, such as 'if(FALSE){...}', from your R files?",
+      "Have you add all the files in ./R folder to DESCRIPTION?",
+      "Have you removed the unfinished examples from the vignette?",
+      "Have you add all the references to README and function documentation?",
+      "Have you replaced all of the dontrun{} with donttest{}?",
+      "Have you rebuilt README.md from README.raw.md, using publish_markdown.r? Note that you have to rebuild README.md whenever you modified README.raw.md.",
+      "Have you removed all the par() settings in the examples? Check your documentations by run \"grep 'par(' ./man/*\" from the terminal."
+      )
 }
